@@ -842,7 +842,6 @@ class Casll1(AeroProblem):
         Vi_y = get(Vi_y)
         Vi_z = get(Vi_z)
 
-
         Vi = np.vstack((Vi_x, Vi_y, Vi_z)).T
 
         return Vi
@@ -1002,4 +1001,7 @@ class Casll1(AeroProblem):
                     mirror=self.symmetric_problem
                 )
 
-        return fig.draw(show=show)
+        return fig.draw(
+            show=show,
+            colorbar_title=data_name
+        )
