@@ -38,18 +38,28 @@ e216.Cm_function = lambda alpha, Re, mach, deflection: (  # Moment coefficient f
     -0.15  # TODO
 )  # TODO make this an actual curve!
 
-rae2822 = Airfoil(
-    CL_function=lambda alpha, Re, mach, deflection,: (  # Lift coefficient function
-        Cl_rae2822(alpha=alpha, Re_c=Re)
-    ),
-    CDp_function=lambda alpha, Re, mach, deflection,: (  # Profile drag coefficient function
-            Cd_profile_rae2822(alpha=alpha, Re_c=Re) +
-            Cd_wave_rae2822(Cl=Cl_rae2822(alpha=alpha, Re_c=Re), mach=mach)
-    ),
-    Cm_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
-        -0.05
-    )  # TODO make this an actual curve!
+rae2822 = Airfoil("rae2822")
+rae2822.CL_function = lambda alpha, Re, mach, deflection: (  # Lift coefficient function
+    Cl_rae2822(alpha=alpha, Re_c=Re)
 )
+rae2822.CDp_function = lambda alpha, Re, mach, deflection: (  # Profile drag coefficient function
+        Cd_profile_rae2822(alpha=alpha, Re_c=Re) +
+        Cd_wave_rae2822(Cl=Cl_rae2822(alpha=alpha, Re_c=Re), mach=mach)
+)
+rae2822.Cm_function = lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
+    -0.05
+)  # TODO make this an actual curve!
+
+naca0008 = Airfoil("naca0008")
+naca0008.CL_function = lambda alpha, Re, mach, deflection: (  # Lift coefficient function
+    Cl_flat_plate(alpha=alpha, Re_c=Re) # TODO fit this to actual data
+)
+naca0008.CDp_function = lambda alpha, Re, mach, deflection: (  # Profile drag coefficient function
+        (1 + (alpha / 5) ** 2) * 2 * Cf_flat_plate(Re_L=Re) # TODO fit this to actual data
+)
+naca0008.Cm_function = lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
+    0
+)  # TODO make this an actual curve!
 
 flat_plate = Airfoil(
     CL_function=lambda alpha, Re, mach, deflection,: (  # Lift coefficient function
